==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/datasafe/requests/PatchTargetAlertPolicyAssociationRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/datasafe/PatchTargetAlertPolicyAssociationExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * PatchTargetAlertPolicyAssociationRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class PatchTargetAlertPolicyAssociationRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails> {

    /** The details used to patch the target-alert policy associations. */
    private com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
            patchTargetAlertPolicyAssociationDetails;

    /** The details used to patch the target-alert policy associations. */
    public com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
            getPatchTargetAlertPolicyAssociationDetails() {
        return patchTargetAlertPolicyAssociationDetails;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails getBody$() {
        return patchTargetAlertPolicyAssociationDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    PatchTargetAlertPolicyAssociationRequest,
                    com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The details used to patch the target-alert policy associations. */
        private com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
                patchTargetAlertPolicyAssociationDetails = null;

        /**
         * The details used to patch the target-alert policy associations.
         *
         * @param patchTargetAlertPolicyAssociationDetails the value to set
         * @return this builder instance
         */
        public Builder patchTargetAlertPolicyAssociationDetails(
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
                        patchTargetAlertPolicyAssociationDetails) {
            this.patchTargetAlertPolicyAssociationDetails =
                    patchTargetAlertPolicyAssociationDetails;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(PatchTargetAlertPolicyAssociationRequest o) {
            patchTargetAlertPolicyAssociationDetails(
                    o.getPatchTargetAlertPolicyAssociationDetails());
            opcRequestId(o.getOpcRequestId());
            ifMatch(o.getIfMatch());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of PatchTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of PatchTargetAlertPolicyAssociationRequest
         */
        public PatchTargetAlertPolicyAssociationRequest build() {
            PatchTargetAlertPolicyAssociationRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails body) {
            patchTargetAlertPolicyAssociationDetails(body);
            return this;
        }

        /**
         * Build the instance of PatchTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of PatchTargetAlertPolicyAssociationRequest
         */
        public PatchTargetAlertPolicyAssociationRequest buildWithoutInvocationCallback() {
            PatchTargetAlertPolicyAssociationRequest request =
                    new PatchTargetAlertPolicyAssociationRequest();
            request.patchTargetAlertPolicyAssociationDetails =
                    patchTargetAlertPolicyAssociationDetails;
            request.opcRequestId = opcRequestId;
            request.ifMatch = ifMatch;
            return request;
            // new
            // PatchTargetAlertPolicyAssociationRequest(patchTargetAlertPolicyAssociationDetails,
            // opcRequestId, ifMatch);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .patchTargetAlertPolicyAssociationDetails(patchTargetAlertPolicyAssociationDetails)
                .opcRequestId(opcRequestId)
                .ifMatch(ifMatch);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",patchTargetAlertPolicyAssociationDetails=")
                .append(String.valueOf(this.patchTargetAlertPolicyAssociationDetails));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof PatchTargetAlertPolicyAssociationRequest)) {
            return false;
        }

        PatchTargetAlertPolicyAssociationRequest other =
                (PatchTargetAlertPolicyAssociationRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.patchTargetAlertPolicyAssociationDetails,
                        other.patchTargetAlertPolicyAssociationDetails)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.patchTargetAlertPolicyAssociationDetails == null
                                ? 43
                                : this.patchTargetAlertPolicyAssociationDetails.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/datasafe/requests/PatchTargetAlertPolicyAssociationRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/datasafe/PatchTargetAlertPolicyAssociationExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * PatchTargetAlertPolicyAssociationRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class PatchTargetAlertPolicyAssociationRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails> {

    /** The details used to patch the target-alert policy associations. */
    private com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
            patchTargetAlertPolicyAssociationDetails;

    /** The details used to patch the target-alert policy associations. */
    public com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
            getPatchTargetAlertPolicyAssociationDetails() {
        return patchTargetAlertPolicyAssociationDetails;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails getBody$() {
        return patchTargetAlertPolicyAssociationDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    PatchTargetAlertPolicyAssociationRequest,
                    com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The details used to patch the target-alert policy associations. */
        private com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
                patchTargetAlertPolicyAssociationDetails = null;

        /**
         * The details used to patch the target-alert policy associations.
         *
         * @param patchTargetAlertPolicyAssociationDetails the value to set
         * @return this builder instance
         */
        public Builder patchTargetAlertPolicyAssociationDetails(
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails
                        patchTargetAlertPolicyAssociationDetails) {
            this.patchTargetAlertPolicyAssociationDetails =
                    patchTargetAlertPolicyAssociationDetails;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(PatchTargetAlertPolicyAssociationRequest o) {
            patchTargetAlertPolicyAssociationDetails(
                    o.getPatchTargetAlertPolicyAssociationDetails());
            opcRequestId(o.getOpcRequestId());
            ifMatch(o.getIfMatch());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of PatchTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of PatchTargetAlertPolicyAssociationRequest
         */
        public PatchTargetAlertPolicyAssociationRequest build() {
            PatchTargetAlertPolicyAssociationRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.PatchTargetAlertPolicyAssociationDetails body) {
            patchTargetAlertPolicyAssociationDetails(body);
            return this;
        }

        /**
         * Build the instance of PatchTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of PatchTargetAlertPolicyAssociationRequest
         */
        public PatchTargetAlertPolicyAssociationRequest buildWithoutInvocationCallback() {
            PatchTargetAlertPolicyAssociationRequest request =
                    new PatchTargetAlertPolicyAssociationRequest();
            request.patchTargetAlertPolicyAssociationDetails =
                    patchTargetAlertPolicyAssociationDetails;
            request.opcRequestId = opcRequestId;
            request.ifMatch = ifMatch;
            return request;
            // new
            // PatchTargetAlertPolicyAssociationRequest(patchTargetAlertPolicyAssociationDetails,
            // opcRequestId, ifMatch);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .patchTargetAlertPolicyAssociationDetails(patchTargetAlertPolicyAssociationDetails)
                .opcRequestId(opcRequestId)
                .ifMatch(ifMatch);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",patchTargetAlertPolicyAssociationDetails=")
                .append(String.valueOf(this.patchTargetAlertPolicyAssociationDetails));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof PatchTargetAlertPolicyAssociationRequest)) {
            return false;
        }

        PatchTargetAlertPolicyAssociationRequest other =
                (PatchTargetAlertPolicyAssociationRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.patchTargetAlertPolicyAssociationDetails,
                        other.patchTargetAlertPolicyAssociationDetails)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.patchTargetAlertPolicyAssociationDetails == null
                                ? 43
                                : this.patchTargetAlertPolicyAssociationDetails.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        return result;
    }
}
